@@ -23,11 +23,11 @@ from messagebird.voice_recording import VoiceRecordingsList, VoiceRecording
 from messagebird.voice_transcription import VoiceTranscriptionsList, VoiceTranscriptionsView
 from messagebird.call_flow import CallFlow, CallFlowList, CallFlowNumberList
 from messagebird.number import Number, NumberList
+from messagebird.version import VERSION
 
 ENDPOINT = 'https://rest.messagebird.com'
-CLIENT_VERSION = '2.0.0'
 PYTHON_VERSION = '%d.%d.%d' % (sys.version_info[0], sys.version_info[1], sys.version_info[2])
-USER_AGENT = 'MessageBird/ApiClient/%s Python/%s' % (CLIENT_VERSION, PYTHON_VERSION)
+USER_AGENT = 'MessageBird/ApiClient/%s Python/%s' % (VERSION, PYTHON_VERSION)
 REST_TYPE = 'rest'
 
 CONVERSATION_API_ROOT = 'https://conversations.messagebird.com/v1/'
@@ -62,7 +62,6 @@ class SignleErrorException(Exception):
         super(SignleErrorException, self).__init__(errorMessage)
 
 
-
 class Client(object):
     def __init__(self, access_key, http_client=None):
         self.access_key = access_key
@@ -290,7 +289,7 @@ class Client(object):
         if params is None:
             params = {}
         params.update({
-            'type' : 'email',
+            'type': 'email',
             'recipient': recipient,
             'originator': originator
         })
@@ -504,12 +503,16 @@ class Client(object):
         query = self._format_query(limit, offset)
         return CallFlowList().load(self.request('call-flows?' + query, 'GET', None, VOICE_TYPE))
 
-    def call_flow_create(self, title, steps, default=False, record=False):
-        params = {'title': title, 'steps': steps, 'default': default, 'record': record}
+    def call_flow_create(self, steps, default=False, record=False, title=None):
+        params = {'steps': steps, 'default': default, 'record': record}
+        if title is not None:
+            params['title'] = title
         return CallFlow().load(self.request('call-flows', 'POST', params, VOICE_TYPE))
 
-    def call_flow_update(self, id, title, steps, default, record):
-        params = {'title': title, 'steps': steps, 'default': default, 'record': record}
+    def call_flow_update(self, id, steps, default, record, title=None):
+        params = {'steps': steps, 'default': default, 'record': record}
+        if title is not None:
+            params['title'] = title
         return CallFlow().load(self.request('call-flows/' + str(id), 'PUT', params, VOICE_TYPE))
 
     def call_flow_delete(self, id):
