@@ -2,20 +2,34 @@ import hashlib
 import hmac
 import base64
 import time
+from warnings import warn
 from collections import OrderedDict
-
 from urllib.parse import urlencode
 
 
 class SignedRequest:
 
     def __init__(self, requestSignature, requestTimestamp, requestBody, requestParameters):
+        """
+        DEPRECATED
+        """
+        warn("signed_request module is deprecated, "
+             "use request_validator module instead",
+             DeprecationWarning, stacklevel=2)
+
         self._requestSignature = requestSignature
         self._requestTimestamp = str(requestTimestamp)
         self._requestBody = requestBody
         self._requestParameters = requestParameters
 
     def verify(self, signing_key):
+        """
+        DEPRECATED
+        """
+        warn("signed_request.verify is deprecated, "
+             "use request_validator.validate_signature instead",
+             DeprecationWarning, stacklevel=2)
+
         payload = self._build_payload()
         expected_signature = base64.b64decode(self._requestSignature)
         calculated_signature = hmac.new(signing_key.encode('latin-1'), payload.encode('latin-1'),
@@ -23,6 +37,13 @@ class SignedRequest:
         return expected_signature == calculated_signature
 
     def is_recent(self, offset=10):
+        """
+        DEPRECATED
+        """
+        warn("signed_request.is_recent is deprecated, "
+             "use request_validator package instead",
+             DeprecationWarning, stacklevel=2)
+
         return int(time.time()) - int(self._requestTimestamp) < offset
 
     def _build_payload(self):
